pub struct AngularMotor {
pub enabled: bool,
pub target_velocity: Scalar,
pub target_position: Scalar,
pub max_torque: Scalar,
pub motor_model: MotorModel,
}Expand description
A motor for driving the angular motion of a RevoluteJoint.
Motors are configured as part of a joint, applying torque to drive the joint towards a target velocity and/or position.
RevoluteJoint::new(entity1, entity2)
.with_motor(
AngularMotor::new(MotorModel::SpringDamper {
frequency: 2.0,
damping_ratio: 1.0,
})
.with_target_position(target_angle)
)Fields
enabled: boolWhether the motor is enabled.
target_velocity: ScalarThe target angular velocity (rad/s).
target_position: ScalarThe target angle (rad) for position control.
max_torque: ScalarThe maximum torque the motor can apply (N·m).
motor_model: MotorModelThe motor model used for computing the motor torque.
Implementations
Sourceimpl AngularMotor
impl AngularMotor
Sourcepub const fn new(motor_model: MotorModel) -> Self
pub const fn new(motor_model: MotorModel) -> Self
Creates a new angular motor with the given motor model.
Sourcepub const fn new_disabled(motor_model: MotorModel) -> Self
pub const fn new_disabled(motor_model: MotorModel) -> Self
Creates a new disabled angular motor with the given motor model.
To enable the motor later, use set_enabled.
Sourcepub const fn set_enabled(&mut self, enabled: bool) -> &mut Self
pub const fn set_enabled(&mut self, enabled: bool) -> &mut Self
Enables or disables the motor.
Sourcepub const fn with_target_velocity(self, velocity: Scalar) -> Self
pub const fn with_target_velocity(self, velocity: Scalar) -> Self
Sets the target angular velocity in radians per second.
Sourcepub const fn with_target_position(self, target_position: Scalar) -> Self
pub const fn with_target_position(self, target_position: Scalar) -> Self
Sets the target position.
Sourcepub const fn with_max_torque(self, max_torque: Scalar) -> Self
pub const fn with_max_torque(self, max_torque: Scalar) -> Self
Sets the maximum torque the motor can apply.
Sourcepub const fn with_motor_model(self, motor_model: MotorModel) -> Self
pub const fn with_motor_model(self, motor_model: MotorModel) -> Self
Sets the motor model used for computing the motor torque.