pub struct LinearMotor {
pub enabled: bool,
pub target_velocity: Scalar,
pub target_position: Scalar,
pub max_force: Scalar,
pub motor_model: MotorModel,
}Expand description
A motor for driving the linear motion of a PrismaticJoint.
Motors are configured as part of a joint, applying force to drive the joint towards a target velocity and/or position.
Spring-Damper Model
For stable position control that behaves consistently across different configurations,
use MotorModel::SpringDamper. This uses implicit Euler integration for
unconditional stability.
PrismaticJoint::new(entity1, entity2)
.with_motor(
LinearMotor::new(MotorModel::SpringDamper {
frequency: 2.0,
damping_ratio: 1.0,
})
.with_target_position(target_position)
)Fields
enabled: boolWhether the motor is enabled.
target_velocity: ScalarThe target linear velocity (m/s).
target_position: ScalarThe target position (m) for position control.
max_force: ScalarThe maximum force the motor can apply (N).
motor_model: MotorModelThe motor model used for computing the motor force.
Implementations
Sourceimpl LinearMotor
impl LinearMotor
Sourcepub const fn new(motor_model: MotorModel) -> Self
pub const fn new(motor_model: MotorModel) -> Self
Creates a new linear motor with the given motor model.
Sourcepub const fn new_disabled(motor_model: MotorModel) -> Self
pub const fn new_disabled(motor_model: MotorModel) -> Self
Creates a new disabled linear motor with the given motor model.
To enable the motor later, use set_enabled.
Sourcepub const fn set_enabled(&mut self, enabled: bool) -> &mut Self
pub const fn set_enabled(&mut self, enabled: bool) -> &mut Self
Enables or disables the motor.
Sourcepub const fn with_target_velocity(self, velocity: Scalar) -> Self
pub const fn with_target_velocity(self, velocity: Scalar) -> Self
Sets the target linear velocity in meters per second.
Sourcepub const fn with_target_position(self, target_position: Scalar) -> Self
pub const fn with_target_position(self, target_position: Scalar) -> Self
Sets the target position.
Sourcepub const fn with_max_force(self, max_force: Scalar) -> Self
pub const fn with_max_force(self, max_force: Scalar) -> Self
Sets the maximum force the motor can apply.
Sourcepub const fn with_motor_model(self, motor_model: MotorModel) -> Self
pub const fn with_motor_model(self, motor_model: MotorModel) -> Self
Sets the motor model used for computing the motor force.